
package eu.etaxonomy.taxeditor.navigation;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IMemento;

import eu.etaxonomy.taxeditor.model.ContextListenerAdapter;
import eu.etaxonomy.taxeditor.navigation.navigator.TaxonNavigator;
import eu.etaxonomy.taxeditor.preference.CdmPreferences;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

/**
 * <p>NavigatorStateManager class.</p>
 *
 * @author n.hoffmann
 * @created Apr 1, 2010
 * @version 1.0
 */
public class NavigatorStateManager extends ContextListenerAdapter {
	
	/**
	 * {@inheritDoc}
	 *
	 * Tries to restore the state of the taxon editor and the navigator when a context starts.
	 */
	@Override
	public void contextStart(IMemento memento, IProgressMonitor monitor) {
		TaxonNavigator navigator = NavigationUtil.getNavigator(true);
		if(navigator != null){
			navigator.init();
			if (PreferencesUtil.isStoreNavigatorState()){
				navigator.restore(memento, monitor);
			} else {
				navigator.restore(null, monitor);
			}
			
		}
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.model.ContextListenerAdapter#contextRefresh(org.eclipse.core.runtime.IProgressMonitor)
	 */
	@Override
	public void contextRefresh(IProgressMonitor monitor) {
		TaxonNavigator navigator = NavigationUtil.getNavigator(true);
		if(navigator != null){
			navigator.refresh();
		}
	}
	
	/**
	 * {@inheritDoc}
	 *
	 * If the context
	 */
	@Override
	public void contextStop(IMemento memento, IProgressMonitor monitor) {
		saveNavigatorState(memento, monitor);
		clearNavigator();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.model.ContextListenerAdapter#workbenchShutdown(org.eclipse.ui.IMemento, org.eclipse.core.runtime.IProgressMonitor)
	 */
	/** {@inheritDoc} */
	@Override
	public void workbenchShutdown(IMemento memento, IProgressMonitor monitor) {
		saveNavigatorState(memento, monitor);
	
	}
	
	/**
	 * @param memento
	 */
	private void saveNavigatorState(IMemento memento, IProgressMonitor monitor) {
		TaxonNavigator navigator = NavigationUtil.getNavigator(false);
		if(navigator != null){
			navigator.save(memento, monitor);
		}
	}
	
	/**
	 * Removes all content form the TaxonNavigator
	 */
	private void clearNavigator() {
		TaxonNavigator navigator = NavigationUtil.getNavigator(false);
		if(navigator != null){
			navigator.clear();
		}
	}

}
