/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.key.polytomous.handler;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.widgets.Display;

import eu.etaxonomy.cdm.model.description.PolytomousKey;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.navigation.key.polytomous.PolytomousKeyViewPart;

/**
 * @author n.hoffmann
 * @created Dec 3, 2010
 * @version 1.0
 */
public class EditPolytomousKeyNodesHandler extends AbstractHandler {

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		PolytomousKeyViewPart view = (PolytomousKeyViewPart) NavigationUtil.getView(PolytomousKeyViewPart.ID, false);
		
		ISelection selection = view.getSite().getSelectionProvider().getSelection(); 
		if(selection instanceof StructuredSelection){
		   
			final StructuredSelection structuredSelection = (StructuredSelection) selection;
			
			Job job = new Job("Opening Polytomous Keys"){

				@Override
				protected IStatus run(IProgressMonitor monitor) {
					monitor.beginTask("Opening Polytomous Keys", structuredSelection.size());
					
					for(final Object selectedObject : structuredSelection.toArray()){
						if(selectedObject instanceof PolytomousKey){
							
							Display.getDefault().asyncExec(new Runnable(){

								@Override
								public void run() {								    
									NavigationUtil.openEditor((PolytomousKey) selectedObject);
								}
								
							});
							monitor.worked(1);
						}
					}
					monitor.done();
					return Status.OK_STATUS;
				}
				
			};
			
			job.setPriority(Job.SHORT);
			job.schedule();			
			
		}
		return null;
	}

}
