/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.navigation.key.polytomous.operation;

import java.util.UUID;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;

import eu.etaxonomy.cdm.api.application.CdmChangeEvent.Action;
import eu.etaxonomy.cdm.api.service.IPolytomousKeyService;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.taxeditor.operation.RemotingCdmUpdateOperation;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author cmathew
 * @date 29 Jun 2015
 *
 */
public class RemotingUpdatePolytomousKeyAllNodesOperation extends RemotingCdmUpdateOperation {

    private final UUID polytomousKeyUuid;
    /**
     * @param label
     * @param action
     * @param source
     * @param async
     */
    public RemotingUpdatePolytomousKeyAllNodesOperation(Object source,
            boolean async,
            UUID polytomousKeyUuid) {
        super(LABEL, Action.Update, source, async);
        this.polytomousKeyUuid = polytomousKeyUuid;

    }

    public RemotingUpdatePolytomousKeyAllNodesOperation(Object source,
            boolean async) {
        super(LABEL, Action.Update, source, async);
        // this implies that we have to update all nodes of all keys
        this.polytomousKeyUuid = null;
    }

    private final static String LABEL = "Update All Polytomous Key Nodes operation";

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.operation.RemotingCdmUpdateOperation#doUpdateExecute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
     */
    @Override
    protected UpdateResult doUpdateExecute(IProgressMonitor monitor, IAdaptable info) throws Exception {
        if(polytomousKeyUuid == null) {
            return CdmStore.getService(IPolytomousKeyService.class).updateAllNodeNumberings();
        } else {
            return CdmStore.getService(IPolytomousKeyService.class).updateAllNodeNumberings(polytomousKeyUuid);
        }
    }

}
