package eu.etaxonomy.taxeditor.navigation.navigator.handler;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.navigation.navigator.TaxonNavigator;
import eu.etaxonomy.taxeditor.navigation.operation.CloneClassificationOperation;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.section.classification.CloneClassificationWizard;

public class CloneClassificationHandler extends AbstractHandler {

    @SuppressWarnings("unused")
    private static final Logger logger = Logger.getLogger(CloneClassificationHandler.class);

    @Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
        ISelection currentSelection = HandlerUtil.getCurrentSelection(event);
        if (currentSelection instanceof IStructuredSelection) {
            Object selectedElement = ((IStructuredSelection) currentSelection).getFirstElement();
            if (selectedElement instanceof Classification) {
                Classification classification = (Classification) selectedElement;
                TaxonNavigator taxonNavigator = (TaxonNavigator)AbstractUtility.showView(TaxonNavigator.ID);
                CloneClassificationWizard wizard = new CloneClassificationWizard(classification);
                WizardDialog dialog = new WizardDialog(Display.getCurrent().getActiveShell(), wizard);
                dialog.open();

                String classificationName = wizard.getClassificationName();
                TaxonRelationshipType relationType = wizard.getRelationType();
                Reference reference = wizard.getReference();

                CloneClassificationOperation operation = new CloneClassificationOperation("Clone classification",
                        StoreUtil.getUndoContext(), classification, classificationName, reference, relationType,
                        NavigationUtil.getNavigator(false), NavigationUtil.getNavigator(false));

                AbstractUtility.executeOperation(operation);
                taxonNavigator.refresh();
            }
        }
        return null;
    }

}
