/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.navigation.navigator.operation;

import java.util.UUID;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;

import eu.etaxonomy.cdm.api.application.CdmApplicationState;
import eu.etaxonomy.cdm.api.application.CdmChangeEvent.Action;
import eu.etaxonomy.cdm.api.service.ITaxonNodeService;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.taxeditor.operation.RemotingCdmUpdateOperation;


/**
 * @author cmathew
 * @date 17 Jun 2015
 *
 */
public class RemotingChangeAcceptedTaxonToSynonymOperation extends RemotingCdmUpdateOperation {

    private final UUID oldTaxonNodeUuid;
    private final UUID newAcceptedTaxonNodeUuid;


    private final static String LABEL = "Change Accepted Taxon to Synonym operation";

    /**
     * @param label
     */
    public RemotingChangeAcceptedTaxonToSynonymOperation(Object source,
            boolean async,
            UUID oldTaxonNodeUuid,
            UUID newAcceptedTaxonNodeUuid) {
        super(LABEL, Action.Update, source, async);
        this.oldTaxonNodeUuid = oldTaxonNodeUuid;
        this.newAcceptedTaxonNodeUuid = newAcceptedTaxonNodeUuid;
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.operation.RemotingCdmUpdateOperation#doUpdateExecute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
     */
    @Override
    protected UpdateResult doUpdateExecute(IProgressMonitor monitor, IAdaptable info) throws Exception {
        return CdmApplicationState.getService(ITaxonNodeService.class).makeTaxonNodeASynonymOfAnotherTaxonNode(oldTaxonNodeUuid,
                newAcceptedTaxonNodeUuid,
                null,
                null,
                null);
    }

}
